@@ -55,7 +55,7 @@
 //! It may seem reasonable to expect numbers that differ by less than 0.000001 to be equal, but
 //! this does not always work well (consider comparing -0.0000000028 to +0.00000097).
 
-extern crate num;
+extern crate num_traits as num;
 use num::Zero;
 
 use std::mem;
@@ -210,7 +210,7 @@ impl ApproxEqUlps for f32 {
 fn f32_approx_eq_test1() {
     let f: f32 = 0.1_f32;
     let mut sum: f32 = 0.0_f32;
-    for _ in (0_isize..10_isize) { sum += f; }
+    for _ in 0_isize..10_isize { sum += f; }
     let product: f32 = f * 10.0_f32;
     assert!(sum != product); // Should not be directly equal:
     println!("Ulps Difference: {}",sum.ulps(&product));
@@ -254,7 +254,7 @@ impl ApproxEqUlps for f64 {
 fn f64_approx_eq_test1() {
     let f: f64 = 0.1_f64;
     let mut sum: f64 = 0.0_f64;
-    for _ in (0_isize..10_isize) { sum += f; }
+    for _ in 0_isize..10_isize { sum += f; }
     let product: f64 = f * 10.0_f64;
     assert!(sum != product); // Should not be directly equal:
     println!("Ulps Difference: {}",sum.ulps(&product));
@@ -359,7 +359,7 @@ impl ApproxOrdUlps for f32 {
 fn f32_approx_cmp_test1() {
     let f: f32 = 0.1_f32;
     let mut sum: f32 = 0.0_f32;
-    for _ in (0_isize..10_isize) { sum += f; }
+    for _ in 0_isize..10_isize { sum += f; }
     let product: f32 = f * 10.0_f32;
     assert!(sum != product); // Should not be directly equal:
     println!("Ulps Difference: {}",sum.ulps(&product));
@@ -406,7 +406,7 @@ impl ApproxOrdUlps for f64 {
 fn f64_approx_cmp_test1() {
     let f: f64 = 0.000000001_f64;
     let mut sum: f64 = 0.0_f64;
-    for _ in (0_isize..10_isize) { sum += f; }
+    for _ in 0_isize..10_isize { sum += f; }
     let product: f64 = f * 10.0_f64;
     assert!(sum != product); // Should not be directly equal:
     println!("Ulps Difference: {}",sum.ulps(&product));
